#!/bin/bash
############################################################
# This Shell script and the embeded python scripts are used to
# Download Predictor and Predictand Data, and generate plots
# for Seasonal CCA Downscaled Precip Forecasts
# for the domain of your interest
# Written by Endalkachew Bekele, NOAA/CPC/International Desks, August 2024
# seasonal_calib_python.sh (version 1.0)

LANG=en_US.utf8
LC_ALL=en_US.utf8
unameout="$(uname -s)"

if [ "$#" -ne 4 ]; then
    echo "***************************************************************************************************************************"
    echo " error while running plot_all.sh"
    echo "----------------- You need to provide 4 arguments -------------------------------------------------------------------------"
    echo "***************************************************************************************************************************"
    echo
    echo "The four arguments reflect geographical extent of your area:"
    echo
    echo "western lon, eastern lon, southern lat and northern lat in degreas, respectively"
    echo
    echo "Use negative sign for longitudes in western, and latitudes in the southern hemisphere"
    echo
    echo "For example, if your area extends from 18W to 11W and from 12N to 17N .."
    echo " you may run the script as .."
    echo
    echo " bash seasonal_calib_python.sh -18 -11 12 17"
    echo
    echo
exit
fi

rm *.py

# Global Tropics
w=-180; e=180; s=-30; n=30
# Tropical Indian Ocean
#w=35; e=105; s=-20; n=20
# Tropical North Atlantic
#w=-70; e=14; s=0; n=40

export W=$w
export E=$e
export S=$s
export N=$n

bash gen_nmme_precip_raw.sh $1 $2 $3 $4
bash gen_ersstv5_sst_cca.sh $1 $2 $3 $4
bash gen_nmme_sst_cca.sh $1 $2 $3 $4
bash gen_nmme_precip_cca.sh $1 $2 $3 $4

if [ $unameout = "Darwin" ]; then
   /Applications/Google\ Chrome.app/Contents/MacOS/Google\ Chrome index.html&
   open -a Safari index.html&
else
    firefox index.html&
    google-chrome index.html&
    cygstart index.html
fi


